<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Detalii</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Presupuneri</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Găsit</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Mare</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Ratat</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Joc terminat</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 punct din %n</numerusform>
            <numerusform>%1 puncte din %n</numerusform>
            <numerusform>%1 puncte din %n</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 din %n punct</numerusform>
            <numerusform>3 din %n puncte</numerusform>
            <numerusform>3 din %n puncte</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 din %n punct</numerusform>
            <numerusform>2 din %n puncte</numerusform>
            <numerusform>2 din %n puncte</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 din %n punct</numerusform>
            <numerusform>1 din %n puncte</numerusform>
            <numerusform>1 din %n puncte</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 din %n punct</numerusform>
            <numerusform>0 din %n puncte</numerusform>
            <numerusform>0 din %n puncte</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punct</numerusform>
            <numerusform>%n puncte</numerusform>
            <numerusform>%n puncte</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Punctajul maxim a fost calculat din următoarele treizeci de cuvinte:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n presupunere</numerusform>
            <numerusform>%n presupuneri</numerusform>
            <numerusform>%n presupuneri</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n ratare</numerusform>
            <numerusform>%n ratări</numerusform>
            <numerusform>%n ratări</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Clasic</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Reumplere</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Vigoare</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Ratări</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Repartizare</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Disciplină</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Numărătoare inversă de la 30 secunde şi reumplere la presupunerile corecte.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Numărătoare inversă de la 3 minute.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Numărătoare inversă de la 30 secunde şi reumplere la presupunerile corecte.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Numărătoare inversă de la 45 secunde şi pauză la presupunerile corecte.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Jocul se termină după 3 presupuneri greşite.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Jocul se termină după 30 presupuneri.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Numărătoare inversă de la 30 secunde şi creşte sau scade la presupunerile corecte.</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Nelimitat</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation>Jocul se termină cînd sînt găsite toate cuvintele.</translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Nu se pot citi cuburile din fişier.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Nu se poate citi lista cuvintelor din fişier.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Limbaj planşetă</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizat</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Alegeţi...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Notă:&lt;/b&gt; Aceste setări vor avea efect la începerea unui nou joc.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Limbă:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Cuburi:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Listă cuvinte:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Dicţionar:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Alegeţi fişierul cuburi</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Alegeţi fişierul listă de cuvinte</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selectaţi limba aplicaţiei:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Limbaj Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notă</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Joc nou</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Cantitate cuvinte:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Mărime minimă cuvinte:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Mică</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medie</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Mare</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aleatoare</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n literă</numerusform>
            <numerusform>%n litere</numerusform>
            <numerusform>%n litere</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Scoruri record</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Scor</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Rang</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Mărime</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Felicitări!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Ţi-ai bătut cel mai bun scor!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Felicitări!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Ai un nou scor mare!</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Indisponibil</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;În pauză&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Clic petru a relua jocul.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Vă rugăm aşteptaţi&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Încărcare joc...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Clic pentru a începe joc nou.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Vă rugăm aşteptaţi&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generare planşetă nouă...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Vă rugăm aşteptaţi&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizare listă cuvinte...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Joc &amp;nou...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>Pornire &amp;nouă</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>Alegeţi...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>Distribuie...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>Sfîrşit</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauză</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalii</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Scoruri record</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Arată scor &amp;maxim</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Niciodată</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>Sfîrşitul jocului</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>Mereu</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Arată cuvinte &amp;ratate</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Arată numărul de cuvinte</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>Limbaj planşetă...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Limbă aplicaţie...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controale</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Toate drepturile rezervate &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Varianta un singur jucător a  &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lansat sub licenţă &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Lista cuvintelor englezeşti este bazată pe &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; de Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Lista cuvintelor ebraice este bazată pe &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; de Nadav Har&apos;El şi Dan Kenigsberg</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Importă joc</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Jocuri Tanglet (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nu se poate începe jocul solicitat.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Exportă joc</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Încheiaţi jocul curent?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalii</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Mărime planşetă:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Mare</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Densitate cuvinte:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Mărime cuvinte:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 sau mai multe litere</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Tip joc:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descriere:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controale</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Joc cu mouse-ul:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selectaţi un cuvînt:&lt;/b&gt; Faceţi click pe literele unui cuvînt.&lt;br&gt;&lt;b&gt;Faceţi o presupunere:&lt;/b&gt; Faceţi click pe ultima literă selectată.&lt;br&gt;&lt;b&gt;Ştergeţi literele:&lt;/b&gt; Faceţi click pe o literă anterior selectată.&lt;br&gt;&lt;b&gt;Ştergeţi cuvînt:&lt;/b&gt; Faceţi clic de două ori pe prima literă selectată.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Joc cu tastatura:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selectaţi un cuvînt:&lt;/b&gt; TTastaţi literele cuvîntului.&lt;br&gt;&lt;b&gt;Faceţi o presupunere:&lt;/b&gt; Apăsaţi Enter.&lt;br&gt;&lt;b&gt;Ştergeţi cuvîntul:&lt;/b&gt; Apăsaţi Ctrl+Backspace.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Litere:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Găsit:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punct</numerusform>
            <numerusform>%n puncte</numerusform>
            <numerusform>%n puncte</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Joc de găsire a cuvintelor</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Un fişier al jocului de jucat.</translation>
    </message>
</context>
</TS>
